Module air

Module air 

Building blocks for defining AIRs.

Macros

chip_name
Macro to get the name of a chip.

Structs

AirInteraction
An interaction is a cross-table lookup.
BinomialExtension
A binomial extension element represented over a generic type T.
InteractionScopeIter
An iterator over the variants of InteractionScope
PublicValues
Stores all of a shard proof’s public values.
ShardBoundary
A shard boundary is a single shard that is being proven.
ShardRange
The range of the shard with respect to the program execution ordering.
SubAirBuilder
A builder used to eval a sub-air. This will handle enforcing constraints for a subset of a trace matrix. E.g. if a particular air needs to be enforced for a subset of the columns of the trace, then the SubAirBuilder can be used.
SubMatrixRowSlices
A submatrix of a matrix. The matrix will contain a subset of the columns of self.inner.

Enums

InteractionScope
The scope of an interaction.

Constants

POSEIDON_NUM_WORDS
The number of field elements in the poseidon2 digest.
PROOF_NONCE_NUM_WORDS
The number of 32 bit words in the SP1 proof’s proof nonce.
PV_DIGEST_NUM_WORDS
The number of 32 bit words in the SP1 proof’s committed value digest.
SP1_PROOF_NUM_PV_ELTS
The number of non padded elements in the SP1 proofs public values vec.

Traits

BaseAirBuilder
A trait which contains basic methods for building an AIR.
ByteAirBuilder
A trait which contains methods for byte interactions in an AIR.
EmptyMessageBuilder
A message builder for which sending and receiving messages is a no-op.
ExtensionAirBuilder
A builder that can operation on extension elements.
InstructionAirBuilder
A trait which contains methods related to RISC-V instruction interactions in an AIR.
MachineAir
An AIR that is part of a multi table AIR arithmetization.
MachineAirBuilder
A trait that contains the common helper methods for building SP1 recursion and SP1 machine AIRs.
MachineProgram
A program that defines the control flow of a machine through a program counter.
MessageBuilder
A builder that can send and receive messages (or interactions) with other AIRs.
SP1AirBuilder
A trait which contains all helper methods for building SP1 machine AIRs.
SepticExtensionAirBuilder
A builder that can operation on septic extension elements.

Functions

timestamp_from_limbs
Returns a timestamp from a limbs array.

Type Aliases

SP1CorePublicValues
A type alias for the public values of the SP1 core proof.

Derive Macros

MachineAir