#[repr(C)]pub struct BinomialExtension<T>(pub [T; 4]);Expand description
A binomial extension element represented over a generic type T.
Tuple Fields
0: [T; 4]Implementations
Sourceimpl<T> BinomialExtension<T>
impl<T> BinomialExtension<T>
Sourcepub fn from_base(b: T) -> Selfwhere
T: AbstractField,
pub fn from_base(b: T) -> Selfwhere
T: AbstractField,
Creates a new binomial extension element from a base element.
Sourcepub const fn as_base_slice(&self) -> &[T]
pub const fn as_base_slice(&self) -> &[T]
Returns a reference to the underlying slice.
Sourcepub fn from<S: Into<T> + Clone>(from: BinomialExtension<S>) -> Self
pub fn from<S: Into<T> + Clone>(from: BinomialExtension<S>) -> Self
Creates a new binomial extension element from a binomial extension element.
Sourceimpl<F> BinomialExtension<F>where
F: BinomiallyExtendable<4>,
impl<F> BinomialExtension<F>where
F: BinomiallyExtendable<4>,
Sourcepub fn try_inverse(&self) -> Option<Self>
pub fn try_inverse(&self) -> Option<Self>
Returns the multiplicative inverse of the element, if it exists.