MachineProgram

Trait MachineProgram 

pub trait MachineProgram<F>: Send + Sync {
    // Required methods
    fn pc_start(&self) -> [F; 3];
    fn initial_global_cumulative_sum(&self) -> SepticDigest<F>;
    fn enable_untrusted_programs(&self) -> F;
}
A program that defines the control flow of a machine through a program counter.

Required Methods

fn pc_start(&self) -> [F; 3]

Gets the starting program counter.

fn initial_global_cumulative_sum(&self) -> SepticDigest<F>

Gets the initial global cumulative sum.

fn enable_untrusted_programs(&self) -> F

Gets the flag indicating if untrusted programs are allowed.

Implementors