InteractionKind

Enum InteractionKind 

pub enum InteractionKind {
Show 18 variants Memory = 1, Program = 2, Byte = 5, State = 7, Syscall = 8, Global = 9, ShaExtend = 10, ShaCompress = 11, Keccak = 12, GlobalAccumulation = 13, MemoryGlobalInitControl = 14, MemoryGlobalFinalizeControl = 15, InstructionFetch = 16, InstructionDecode = 17, PageProt = 18, PageProtAccess = 19, PageProtGlobalInitControl = 20, PageProtGlobalFinalizeControl = 21,
}
The type of interaction for a lookup argument.

Variants



Memory = 1

Interaction with the memory table, such as read and write.



Program = 2

Interaction with the program table, loading an instruction at a given pc address.



Byte = 5

Interaction with the byte lookup table for byte operations.



State = 7

Interaction with the current CPU state.



Syscall = 8

Interaction with a syscall.



Global = 9

Interaction with the global table.



ShaExtend = 10

Interaction with the ShaExtend chip.



ShaCompress = 11

Interaction with the ShaCompress chip.



Keccak = 12

Interaction with the Keccak chip.



GlobalAccumulation = 13

Interaction to accumulate the global interaction digests.



MemoryGlobalInitControl = 14

Interaction with the MemoryGlobalInit chip.



MemoryGlobalFinalizeControl = 15

Interaction with the MemoryGlobalFinalize chip.



InstructionFetch = 16

Interaction with the instruction fetch table.



InstructionDecode = 17

Interaction with the instruction decode table.



PageProt = 18

Interaction with the page prot chip.



PageProtAccess = 19

Interaction with the page prot chip.



PageProtGlobalInitControl = 20

Interaction with the PageProtGlobalInit chip.



PageProtGlobalFinalizeControl = 21

Interaction with the PageProtGlobalFinalize chip.

Implementations

Source

impl InteractionKind

pub fn all_kinds() -> Vec<InteractionKind>

Returns all kinds of interactions.

pub fn num_values(&self) -> usize

The number of values sent and received for each interaction kind.

pub fn appears_in_eval_public_values(&self) -> bool

Whether this interaction kind gets used in eval_public_values.