pub enum LogupGkrVerificationError<EF> {
InconsistentSumcheckClaim(usize),
InconsistentEvaluation(usize),
SumcheckError(SumcheckError),
InvalidShape,
InvalidFirstLayerDimension(u32, u32),
InvalidLastLayerDimension(usize, usize),
TracePointMismatch,
CumulativeSumMismatch(EF, EF),
NumeratorEvaluationMismatch(EF, EF),
DenominatorEvaluationMismatch(EF, EF),
ZeroDenominator,
}Expand description
An error type for LogUp GKR.
Variants
InconsistentSumcheckClaim(usize)
The sumcheck claim is not consistent with the calculated one from the prover messages.
InconsistentEvaluation(usize)
Inconsistency between the calculated evaluation and the sumcheck evaluation.
SumcheckError(SumcheckError)
Error when verifying sumcheck proof.
InvalidShape
The proof shape does not match the expected one for the given number of interactions.
InvalidFirstLayerDimension(u32, u32)
The size of the first layer does not match the expected one.
InvalidLastLayerDimension(usize, usize)
The dimension of the last layer does not match the expected one.
TracePointMismatch
The trace point does not match the claimed opening point.
CumulativeSumMismatch(EF, EF)
The cumulative sum does not match the claimed one.
NumeratorEvaluationMismatch(EF, EF)
The numerator evaluation does not match the expected one.
DenominatorEvaluationMismatch(EF, EF)
The denominator evaluation does not match the expected one.
ZeroDenominator
The denominator guts had zero in it.