debug_constraints_all_chips

Function debug_constraints_all_chips 

pub fn debug_constraints_all_chips<GC, A>(
    chips: &[Chip<GC::F, A>],
    preprocessed: &Traces<GC::F, CpuBackend>,
    main: &Traces<GC::F, CpuBackend>,
    public_values: &[GC::F],
)
where GC: IopCtx, A: MachineAir<GC::F> + for<'a> Air<DebugConstraintBuilder<'a, GC::F, GC::EF>>,
Checks that the constraints of all the given AIRs are satisfied on the proposed witnesses sent in main and preprocessed.