next_multiple_of_32

Function next_multiple_of_32 

pub fn next_multiple_of_32(n: usize, fixed_height: Option<usize>) -> usize
Returns the internal value of the option if it is set, otherwise returns the next multiple of 32.