Base types, enums, and structs for the constraint compiler.
Structs
- Ast
- Ast for the constraint compiler.
- Attribute
- Attributes of function input parameters
- Constraint
Compiler - The constraint compiler that records the constraints of a chip.
- Func
- Represents a function, containing its name, input/output shapes, and its body Ast.
- FuncCtx
- Function context to keep track of the (number of) inputs and outputs within a function call.
- Func
Decl - Represents the “shape” of a function. It only contains the name, input shape, and output shape of the function, disregarding what the function actually constraints/computes.
Enums
- BinOp
- A binary operation used in the constraint compiler.
- Expr
ExtRef - The [
ExtensionField] for the constraint compiler. - ExprRef
- The
AB::Exprof the constraint compiler. Note that for the constraint compiler, this is alsoAB::Var. - IrVar
- The underlying values that back the constraint compiler.
- OpExpr
- An operation in the IR.
- Picus
Arg - Whether a parameter to a function is an input to a deterministic output, or if that parameter itself should be considered a deterministic output.
- Shape
- Shapes of input type to
SP1Operation
Statics
- GLOBAL_
AST - This should only be used under two scenarios:
Traits
- SP1Operation
Output - Trait for handling operation outputs in SP1.