pub enum ExprRef<F> {
IrVar(IrVar<F>),
Expr(usize),
}Expand description
The AB::Expr of the constraint compiler. Note that for the constraint
compiler, this is also AB::Var.
Variants
IrVar(IrVar<F>)
An IrVar, usually this comes from the chip/inputs.
Expr(usize)
An expression where its value i means this expression represents the
value of the i-th assignment. For the constraint compiler, since it
uses an SSA-style IR, i also means this expression represents the
result of the i-th computation.
Implementations
Sourceimpl<F: Field> ExprRef<F>
impl<F: Field> ExprRef<F>
Sourcepub fn preprocessed(index: usize) -> Self
pub fn preprocessed(index: usize) -> Self
An expression representing a variable from preprocessed trace.
Sourcepub fn input_arg(ctx: &mut FuncCtx) -> Self
pub fn input_arg(ctx: &mut FuncCtx) -> Self
An expression representing a variable from input arguments.
Sourcepub fn input_from_struct<T>(ctx: &mut FuncCtx) -> T
pub fn input_from_struct<T>(ctx: &mut FuncCtx) -> T
Get a struct with input arguments.
Given a sized struct that can be flattened to a slice of Self, produce a new struct of
this type where all the fields are replaced with input arguments.
Sourcepub fn output_arg(ctx: &mut FuncCtx) -> Self
pub fn output_arg(ctx: &mut FuncCtx) -> Self
An expression representing a variable from output arguments.
Sourcepub fn output_from_struct<T>(ctx: &mut FuncCtx) -> T
pub fn output_from_struct<T>(ctx: &mut FuncCtx) -> T
Get a struct with output arguments.
Given a sized struct that can be flattened to a slice of Self, produce a new struct of
this type where all the fields are replaced with output arguments.
Sourcepub fn to_lean_string(&self, input_mapping: &HashMap<usize, String>) -> String
pub fn to_lean_string(&self, input_mapping: &HashMap<usize, String>) -> String
Returns the value in Lean-syntax string
Sourcepub fn expr_to_lean_string(&self) -> String
pub fn expr_to_lean_string(&self) -> String
Returns the value in Lean-syntax string, except that it must be an intermediate expression.
Used for the LHS when assigning variables in steps