pub enum Shape<Expr, ExprExt> {
Unit,
Expr(Expr),
ExprExt(ExprExt),
Word([Expr; 4]),
Array(Vec<Box<Shape<Expr, ExprExt>>>),
Struct(String, Vec<(String, Box<Shape<Expr, ExprExt>>)>),
}Expand description
Shapes of input type to SP1Operation
More like poor man’s facet::Facet…
Variants
Unit
A unit type. This should only be used for representing Output shapes.
Expr(Expr)
An arithmetic expression.
ExprExt(ExprExt)
An arithmetic expression over the extension field.
Word([Expr; 4])
A word in the base field.
Array(Vec<Box<Shape<Expr, ExprExt>>>)
An array of shapes of arbitrary size.
Struct(String, Vec<(String, Box<Shape<Expr, ExprExt>>)>)
A flexible struct type that can represent nested structures.
Contains the struct name and a vector of (field_name, field_shape) pairs.
Implementations
Sourceimpl<F: Field, EF: ExtensionField<F>> Shape<ExprRef<F>, ExprExtRef<EF>>
impl<F: Field, EF: ExtensionField<F>> Shape<ExprRef<F>, ExprExtRef<EF>>
Sourcepub fn to_lean_constructor(&self, mapping: &HashMap<usize, String>) -> String
pub fn to_lean_constructor(&self, mapping: &HashMap<usize, String>) -> String
Output the string that would construct a value of this Shape
Sourcepub fn to_lean_destructor(&self) -> String
pub fn to_lean_destructor(&self) -> String
Output the string that would destruct a value of this Shape
Sourcepub fn map_input(
&self,
prefix: String,
input_mapping: &mut HashMap<usize, String>,
)
pub fn map_input( &self, prefix: String, input_mapping: &mut HashMap<usize, String>, )
Calculates the full variable name that corresponds to InputArg(x).
For example,
structure AddOperation where
value : Word SP1Field
def AddOperation.constraints
(b : SP1Field)
(c : SP1Field)
(cols : AddOperation)
(is_real : SP1Field) := sorryExpr(InputArg(3)) then maps to “cols.value[1]” because if you recursively flatten the
input arguments to AddOperation.constraints in argument/field declaration order, then the
element at index 3 corresponds to cols.value[1].
Sourceimpl<Expr, ExprExt> Shape<Expr, ExprExt>
impl<Expr, ExprExt> Shape<Expr, ExprExt>
Sourcepub fn to_lean_type(&self) -> String
pub fn to_lean_type(&self) -> String
Converts the shape to its corresponding Lean type.
SAFETY: all elements of Shape::Array must have the same shape. We use the first item as
the shape.
SAFETY: Shape::Array must be non-empty.