pub struct Ast<Expr, ExprExt> { /* private fields */ }Expand description
Ast for the constraint compiler.
Implementations
Sourceimpl<F: Field, EF: ExtensionField<F>> Ast<ExprRef<F>, ExprExtRef<EF>>
impl<F: Field, EF: ExtensionField<F>> Ast<ExprRef<F>, ExprExtRef<EF>>
Sourcepub fn alloc(&mut self) -> ExprRef<F>
pub fn alloc(&mut self) -> ExprRef<F>
Allocate a new ExprRef and assign the result of the next operation
to it.
In practice, this usually means after calling Self::alloc you would have to push an
OpExpr. For example, when a = b + c, call Self::alloc to allocate the LHS, and
then push the OpExpr representing b + c to self.operations.
Sourcepub fn alloc_array<const N: usize>(&mut self) -> [ExprRef<F>; N]
pub fn alloc_array<const N: usize>(&mut self) -> [ExprRef<F>; N]
Allocate an array of ExprRef of constant size using Self::alloc and assign all of
them to the next operation.
Sourcepub fn alloc_ext(&mut self) -> ExprExtRef<EF>
pub fn alloc_ext(&mut self) -> ExprExtRef<EF>
Same as Self::alloc but for ExprExtRef
Sourcepub fn assert_zero(&mut self, x: ExprRef<F>)
pub fn assert_zero(&mut self, x: ExprRef<F>)
Push an operation that asserts ExprRef x is zero.
Sourcepub fn assert_ext_zero(&mut self, x: ExprExtRef<EF>)
pub fn assert_ext_zero(&mut self, x: ExprExtRef<EF>)
Same for Self::assert_zero but for ExprExtRef.
Sourcepub fn bin_op(&mut self, op: BinOp, a: ExprRef<F>, b: ExprRef<F>) -> ExprRef<F>
pub fn bin_op(&mut self, op: BinOp, a: ExprRef<F>, b: ExprRef<F>) -> ExprRef<F>
Records a binary operation and returns a new ExprRef that represents the result of this
operation.
Sourcepub fn negate(&mut self, a: ExprRef<F>) -> ExprRef<F>
pub fn negate(&mut self, a: ExprRef<F>) -> ExprRef<F>
Same with Self::bin_op but specifically for negation.
Sourcepub fn bin_op_ext(
&mut self,
op: BinOp,
a: ExprExtRef<EF>,
b: ExprExtRef<EF>,
) -> ExprExtRef<EF>
pub fn bin_op_ext( &mut self, op: BinOp, a: ExprExtRef<EF>, b: ExprExtRef<EF>, ) -> ExprExtRef<EF>
Same with Self::bin_op but for ExprExtRef.
Sourcepub fn bin_op_base_ext(
&mut self,
op: BinOp,
a: ExprExtRef<EF>,
b: ExprRef<F>,
) -> ExprExtRef<EF>
pub fn bin_op_base_ext( &mut self, op: BinOp, a: ExprExtRef<EF>, b: ExprRef<F>, ) -> ExprExtRef<EF>
Same with Self::bin_op but for ExprExtRef and ExprRef.
Sourcepub fn neg_ext(&mut self, a: ExprExtRef<EF>) -> ExprExtRef<EF>
pub fn neg_ext(&mut self, a: ExprExtRef<EF>) -> ExprExtRef<EF>
Same with [Self::neg] but for ExprExtRef
Sourcepub fn ext_from_base(&mut self, a: ExprRef<F>) -> ExprExtRef<EF>
pub fn ext_from_base(&mut self, a: ExprRef<F>) -> ExprExtRef<EF>
Get an ExprExtRef from ExprRef
Sourcepub fn send(
&mut self,
message: AirInteraction<ExprRef<F>>,
scope: InteractionScope,
)
pub fn send( &mut self, message: AirInteraction<ExprRef<F>>, scope: InteractionScope, )
Records a send AirInteraction
Sourcepub fn receive(
&mut self,
message: AirInteraction<ExprRef<F>>,
scope: InteractionScope,
)
pub fn receive( &mut self, message: AirInteraction<ExprRef<F>>, scope: InteractionScope, )
Records a receive AirInteraction
Sourcepub fn to_string_pretty(&self, prefix: &str) -> String
pub fn to_string_pretty(&self, prefix: &str) -> String
A String of all the operations with [prefix] padding in the front.
Sourcepub fn call_operation(
&mut self,
name: String,
inputs: Vec<(String, Attribute, Shape<ExprRef<F>, ExprExtRef<EF>>)>,
output: Shape<ExprRef<F>, ExprExtRef<EF>>,
)
pub fn call_operation( &mut self, name: String, inputs: Vec<(String, Attribute, Shape<ExprRef<F>, ExprExtRef<EF>>)>, output: Shape<ExprRef<F>, ExprExtRef<EF>>, )
Records an operation that represents a function call.