pub struct ConstraintCompiler { /* private fields */ }Expand description
The constraint compiler that records the constraints of a chip.
Implementations
Sourceimpl ConstraintCompiler
impl ConstraintCompiler
Sourcepub fn new<A: MachineAir<SP1Field>>(air: &A, num_public_values: usize) -> Self
pub fn new<A: MachineAir<SP1Field>>(air: &A, num_public_values: usize) -> Self
Creates a new ConstraintCompiler
Sourcepub fn with_sizes(
num_public_values: usize,
preprocessed_width: usize,
main_width: usize,
) -> Self
pub fn with_sizes( num_public_values: usize, preprocessed_width: usize, main_width: usize, ) -> Self
Creates a new ConstraintCompiler with specific dimensions.
Sourcepub fn ast(
&self,
) -> Ast<ExprRef<SP1Field>, ExprExtRef<BinomialExtensionField<SP1Field, 4>>>
pub fn ast( &self, ) -> Ast<ExprRef<SP1Field>, ExprExtRef<BinomialExtensionField<SP1Field, 4>>>
Returns the currently recorded AST.
Sourcepub fn register_module(
&mut self,
name: String,
params: Vec<(String, Attribute, Shape<ExprRef<SP1Field>, ExprExtRef<BinomialExtensionField<SP1Field, 4>>>)>,
body: impl FnOnce(&mut Self) -> Shape<ExprRef<SP1Field>, ExprExtRef<BinomialExtensionField<SP1Field, 4>>>,
)
pub fn register_module( &mut self, name: String, params: Vec<(String, Attribute, Shape<ExprRef<SP1Field>, ExprExtRef<BinomialExtensionField<SP1Field, 4>>>)>, body: impl FnOnce(&mut Self) -> Shape<ExprRef<SP1Field>, ExprExtRef<BinomialExtensionField<SP1Field, 4>>>, )
Records a module (that is usually just a function call that represents an operation).
Sourcepub fn modules(
&self,
) -> &BTreeMap<String, Func<ExprRef<SP1Field>, ExprExtRef<BinomialExtensionField<SP1Field, 4>>>>
pub fn modules( &self, ) -> &BTreeMap<String, Func<ExprRef<SP1Field>, ExprExtRef<BinomialExtensionField<SP1Field, 4>>>>
The modules that has been recorded.