Module permutation

Module permutation 

AIR columns for the Poseidon2 hash function.

Structs

Poseidon2Degree3Cols
A column layout for a poseidon2 permutation with degree 3 constraints.
Poseidon2StateCols
A column layout for the intermediate states of a Poseidon2 AIR across all rounds.

Constants

NUM_INTERNAL_ROUNDS_M1
The number of internal rounds minus one.
NUM_POSEIDON2_DEGREE3_COLS
The number of columns in a Poseidon2 AIR with degree 3 constraints.
POSEIDON2_DEGREE3_COL_MAP
A column map for a Poseidon2 AIR with degree 3 constraints.

Traits

Poseidon2Cols
Trait that describes getter functions for the permutation columns.

Functions

permutation_mut
Convert a row to a mutable Poseidon2Cols instance.