shape_from_record

Function shape_from_record 

pub fn shape_from_record<GC: IopCtx, SC: ShardContext<GC>>(
    verifier: &MachineVerifier<GC, SC>,
    record: &<<SC as ShardContext<GC>>::Air as MachineAir<GC::F>>::Record,
) -> Option<CoreProofShape<GC::F, SC::Air>>
Given a record, compute the shape of the resulting shard proof.

This is a standalone function that can be used outside of SimpleProver.