pub struct MemoryPermit { /* private fields */ }Expand description
A memory permit.
Implementations
Sourceimpl MemoryPermit
impl MemoryPermit
Sourcepub fn split(
&mut self,
mem_in_bytes: usize,
) -> Result<MemoryPermit, MemoryPermitError>
pub fn split( &mut self, mem_in_bytes: usize, ) -> Result<MemoryPermit, MemoryPermitError>
Split the memory permit into two.
Panics
Panics if the number of bytes is greater than Self::num_bytes.
Sourcepub async fn increase(
&mut self,
mem_in_bytes: usize,
) -> Result<(), MemoryPermitError>
pub async fn increase( &mut self, mem_in_bytes: usize, ) -> Result<(), MemoryPermitError>
Increase the memory permit by the given number of bytes.
Sourcepub fn release(&mut self, mem_in_bytes: usize) -> Result<(), MemoryPermitError>
pub fn release(&mut self, mem_in_bytes: usize) -> Result<(), MemoryPermitError>
Partially release the memory permit.
This will release the memory permit by the given number of bytes.
Panics
Panics if the number of bytes is greater than Self::num_bytes.