pub struct MemoryPermitting { /* private fields */ }Expand description
A semaphore that can be used to permit memory usage.
Implementations
Sourceimpl MemoryPermitting
impl MemoryPermitting
Sourcepub const MAX: usize
pub const MAX: usize
The maximum number of bytes that can be permitted.
Note: This bound comes from underlying Semaphore.
Sourcepub fn new(mem_in_bytes: usize) -> Self
pub fn new(mem_in_bytes: usize) -> Self
Create a new memory permitting.
Panics if the number of permits is greater than Self::MAX.
Sourcepub fn total_memory(&self) -> usize
pub fn total_memory(&self) -> usize
Get the total memory that can be permitted.
Sourcepub async fn acquire(
&self,
mem_in_bytes: usize,
) -> Result<MemoryPermit, MemoryPermitError>
pub async fn acquire( &self, mem_in_bytes: usize, ) -> Result<MemoryPermit, MemoryPermitError>