pub struct SimpleProver<GC: IopCtx, SC: ShardContext<GC>, C: AirProver<GC, SC>> { /* private fields */ }Expand description
A prover that proves traces sequentially using a single AirProver.
Prioritizes simplicity over performance - suitable for tests and development.
Implementations
Sourceimpl<GC: IopCtx, SC: ShardContext<GC>, C: AirProver<GC, SC>> SimpleProver<GC, SC, C>
impl<GC: IopCtx, SC: ShardContext<GC>, C: AirProver<GC, SC>> SimpleProver<GC, SC, C>
Sourcepub fn new(shard_verifier: ShardVerifier<GC, SC>, prover: C) -> Self
pub fn new(shard_verifier: ShardVerifier<GC, SC>, prover: C) -> Self
Create a new simple prover.
Sourcepub fn verify(
&self,
vk: &MachineVerifyingKey<GC>,
proof: &MachineProof<GC, PcsProof<GC, SC>>,
) -> Result<(), MachineVerifierConfigError<GC, SC::Config>>where
GC::F: PrimeField32,
pub fn verify(
&self,
vk: &MachineVerifyingKey<GC>,
proof: &MachineProof<GC, PcsProof<GC, SC>>,
) -> Result<(), MachineVerifierConfigError<GC, SC::Config>>where
GC::F: PrimeField32,
Verify a machine proof.
Sourcepub fn verifier(&self) -> &MachineVerifier<GC, SC>
pub fn verifier(&self) -> &MachineVerifier<GC, SC>
Get the verifier.
Sourcepub fn challenger(&self) -> GC::Challenger
pub fn challenger(&self) -> GC::Challenger
Get a new challenger.
Sourcepub fn max_log_row_count(&self) -> usize
pub fn max_log_row_count(&self) -> usize
Get the maximum log row count.
Sourcepub fn log_stacking_height(&self) -> u32
pub fn log_stacking_height(&self) -> u32
Get the log stacking height.
Sourcepub fn shape_from_record(
&self,
record: &Record<GC, SC>,
) -> Option<CoreProofShape<GC::F, SC::Air>>
pub fn shape_from_record( &self, record: &Record<GC, SC>, ) -> Option<CoreProofShape<GC::F, SC::Air>>
Given a record, compute the shape of the resulting shard proof.
Sourcepub async fn setup(
&self,
program: Arc<Program<GC, SC>>,
) -> (PreprocessedData<ProvingKey<GC, SC, C>>, MachineVerifyingKey<GC>)
pub async fn setup( &self, program: Arc<Program<GC, SC>>, ) -> (PreprocessedData<ProvingKey<GC, SC, C>>, MachineVerifyingKey<GC>)
Setup the prover for a given program.
Sourcepub async fn prove_shard(
&self,
pk: Arc<ProvingKey<GC, SC, C>>,
record: Record<GC, SC>,
) -> ShardProof<GC, PcsProof<GC, SC>>
pub async fn prove_shard( &self, pk: Arc<ProvingKey<GC, SC, C>>, record: Record<GC, SC>, ) -> ShardProof<GC, PcsProof<GC, SC>>
Prove a shard with a given proving key.
Sourcepub async fn setup_and_prove_shard(
&self,
program: Arc<Program<GC, SC>>,
vk: Option<MachineVerifyingKey<GC>>,
record: Record<GC, SC>,
) -> (MachineVerifyingKey<GC>, ShardProof<GC, PcsProof<GC, SC>>)
pub async fn setup_and_prove_shard( &self, program: Arc<Program<GC, SC>>, vk: Option<MachineVerifyingKey<GC>>, record: Record<GC, SC>, ) -> (MachineVerifyingKey<GC>, ShardProof<GC, PcsProof<GC, SC>>)
Setup and prove a shard in one call.
Sourcepub async fn preprocessed_table_heights(
&self,
pk: Arc<ProvingKey<GC, SC, C>>,
) -> BTreeMap<String, usize>
pub async fn preprocessed_table_heights( &self, pk: Arc<ProvingKey<GC, SC, C>>, ) -> BTreeMap<String, usize>
Get the preprocessed table heights from the proving key.