ZeroCheckPoly

Struct ZeroCheckPoly 

pub struct ZeroCheckPoly<K, F, EF, A> {
    pub air_data: ZerocheckCpuProver<F, EF, A>,
    pub zeta: Point<EF>,
    pub preprocessed_columns: Option<PaddedMle<K>>,
    pub main_columns: PaddedMle<K>,
    pub eq_adjustment: EF,
    pub geq_value: EF,
    pub padded_row_adjustment: EF,
    pub virtual_geq: VirtualGeq<K>,
}
Zerocheck sumcheck polynomial.

Fields

air_data: ZerocheckCpuProver<F, EF, A>

The data that contains the constraint polynomial.

zeta: Point<EF>

The random challenge point at which the polynomial is evaluated.

preprocessed_columns: Option<PaddedMle<K>>

The preprocessed trace.

main_columns: PaddedMle<K>

The main trace.

eq_adjustment: EF

The adjustment factor from the constant part of the eq polynomial.

geq_value: EF

The geq polynomial value. This will be 0 for all zerocheck polys that are at least one non-padded variable.

padded_row_adjustment: EF

Num padded variables. These padded variables are the first-most (e.g. the most significant) variables. The padded row adjustment.

virtual_geq: VirtualGeq<K>

A virtual materialization keeping track the geq polynomial which is used to adjust the sums for airs in which the zero row doesn’t satisfy the constraints.

Implementations

Source

impl<K: Field, F: Field, EF: ExtensionField<F>, AirData> ZeroCheckPoly<K, F, EF, AirData>

pub fn new( air_data: ZerocheckCpuProver<F, EF, AirData>, zeta: Point<EF>, preprocessed_values: Option<PaddedMle<K>>, main_values: PaddedMle<K>, eq_adjustment: EF, geq_value: EF, padded_row_adjustment: EF, virtual_geq: VirtualGeq<K>, ) -> Self

Creates a new ZeroCheckPoly.