pub type Program<GC, SC> = <<SC as ShardContext<GC>>::Air as MachineAir<<GC as IopCtx>::F>>::Program;Expand description
The type of program this prover can make proofs for.
pub type Program<GC, SC> = <<SC as ShardContext<GC>>::Air as MachineAir<<GC as IopCtx>::F>>::Program;The type of program this prover can make proofs for.