#[repr(C)]pub struct SepticCurve<F> {
pub x: SepticExtension<F>,
pub y: SepticExtension<F>,
}Expand description
A septic elliptic curve point on y^2 = x^3 + 45x + 41z^3 over field
F_{p^7} = F_p[z]/(z^7 - 3z - 5).
Fields
x: SepticExtension<F>The x-coordinate of an elliptic curve point.
y: SepticExtension<F>The y-coordinate of an elliptic curve point.
Implementations
Sourceimpl<F: Field> SepticCurve<F>
impl<F: Field> SepticCurve<F>
Sourcepub fn check_on_point(&self) -> bool
pub fn check_on_point(&self) -> bool
Check if a SepticCurve struct is on the elliptic curve.
Sourcepub fn add_incomplete(&self, other: SepticCurve<F>) -> Self
pub fn add_incomplete(&self, other: SepticCurve<F>) -> Self
Adds two elliptic curve points, assuming that the addition doesn’t lead to the exception cases of weierstrass addition.
Sourcepub fn add_assign(&mut self, other: SepticCurve<F>)
pub fn add_assign(&mut self, other: SepticCurve<F>)
Add assigns an elliptic curve point, assuming that the addition doesn’t lead to the exception cases of weierstrass addition.
Sourcepub fn sub_incomplete(&self, other: SepticCurve<F>) -> Self
pub fn sub_incomplete(&self, other: SepticCurve<F>) -> Self
Subtracts two elliptic curve points, assuming that the subtraction doesn’t lead to the exception cases of weierstrass addition.
Sourcepub fn sub_assign(&mut self, other: SepticCurve<F>)
pub fn sub_assign(&mut self, other: SepticCurve<F>)
Subtract assigns an elliptic curve point, assuming that the subtraction doesn’t lead to the exception cases of weierstrass addition.
Sourceimpl<F: AbstractField> SepticCurve<F>
impl<F: AbstractField> SepticCurve<F>
Sourcepub fn curve_formula(x: SepticExtension<F>) -> SepticExtension<F>
pub fn curve_formula(x: SepticExtension<F>) -> SepticExtension<F>
Evaluates the curve formula x^3 + 45x + 41z^3
Sourceimpl<F: PrimeField32> SepticCurve<F>
impl<F: PrimeField32> SepticCurve<F>
Sourcepub fn lift_x(m: [F; 8]) -> (Self, u8, [F; 16], [F; 16])
pub fn lift_x(m: [F; 8]) -> (Self, u8, [F; 16], [F; 16])
Lift an x coordinate into an elliptic curve.
As an x-coordinate may not be a valid one, we allow an additional value in [0, 256) to the
hash input. Also, we always return the curve point with y-coordinate within [1, (p-1)/2], where p is the characteristic. The returned values are the curve point, the
offset used, and the hash input and output.
TODO: this function should maybe take a Perm argument or express the dependency in some way.
Sourceimpl<F: AbstractField> SepticCurve<F>
impl<F: AbstractField> SepticCurve<F>
Sourcepub fn sum_checker_x(
p1: SepticCurve<F>,
p2: SepticCurve<F>,
p3: SepticCurve<F>,
) -> SepticExtension<F>
pub fn sum_checker_x( p1: SepticCurve<F>, p2: SepticCurve<F>, p3: SepticCurve<F>, ) -> SepticExtension<F>
Given three points p1, p2, p3, the function is zero if and only if p3.x == (p1 + p2).x assuming that no weierstrass edge cases occur.
Sourcepub fn sum_checker_y(
p1: SepticCurve<F>,
p2: SepticCurve<F>,
p3: SepticCurve<F>,
) -> SepticExtension<F>
pub fn sum_checker_y( p1: SepticCurve<F>, p2: SepticCurve<F>, p3: SepticCurve<F>, ) -> SepticExtension<F>
Given three points p1, p2, p3, the function is zero if and only if p3.y == (p1 + p2).y assuming that no weierstrass edge cases occur.
Sourceimpl<T> SepticCurve<T>
impl<T> SepticCurve<T>
Sourcepub fn convert<S: Copy, G: FnMut(S) -> T>(point: SepticCurve<S>, f: G) -> Self
pub fn convert<S: Copy, G: FnMut(S) -> T>(point: SepticCurve<S>, f: G) -> Self
Convert a SepticCurve<S> into SepticCurve<T>, with a map that implements FnMut(S) -> T.