Elliptic Curve digests with a starting point to avoid weierstrass addition exceptions.
Structs
- Septic
Digest - A global cumulative sum digest, a point on the elliptic curve that
SepticCurve<F>represents. As these digests start with theCURVE_CUMULATIVE_SUM_STARTpoint, they require special summing logic.
Constants
- CURVE_
CUMULATIVE_ SUM_ START_ X - The x-coordinate for a curve point used as a starting cumulative sum for global permutation
trace generation, derived from
sqrt(2). - CURVE_
CUMULATIVE_ SUM_ START_ Y - The y-coordinate for a curve point used as a starting cumulative sum for global permutation
trace generation, derived from
sqrt(2). - DIGEST_
SUM_ START_ X - The x-coordinate for a curve point used as a starting random point for digest accumulation,
derived from
sqrt(3). - DIGEST_
SUM_ START_ Y - The y-coordinate for a curve point used as a starting random point for digest accumulation,
derived from
sqrt(3).