#[repr(C)]pub struct SepticExtension<F>(pub [F; 7]);Expand description
A septic extension with an irreducible polynomial z^7 - 3z - 5.
The field can be constructed as F_{p^7} = F_p[z]/(z^7 - 3z - 5).
Tuple Fields
0: [F; 7]Implementations
Sourceimpl<F: Field> SepticExtension<F>
impl<F: Field> SepticExtension<F>
Sourceimpl<F: PrimeField32> SepticExtension<F>
impl<F: PrimeField32> SepticExtension<F>
Sourcepub fn is_receive(&self) -> bool
pub fn is_receive(&self) -> bool
Returns whether the extension field element viewed as an y-coordinate of a digest represents a receive interaction.
Sourcepub fn is_send(&self) -> bool
pub fn is_send(&self) -> bool
Returns whether the extension field element viewed as an y-coordinate of a digest represents a send interaction.
Sourcepub fn is_exception(&self) -> bool
pub fn is_exception(&self) -> bool
Returns whether the extension field element viewed as an y-coordinate of a digest cannot represent anything.