pub struct SP1VerifyingKey {
pub vk: MachineVerifyingKey<SP1GlobalContext>,
}Expand description
The information necessary to verify a proof for a given RISC-V program.
Fields
vk: MachineVerifyingKey<SP1GlobalContext>The underlying verifying key, where the underlying field is SP1Field and the digest type
is an array of DIGEST_SIZE SP1Field elements.