pub type OuterSC<A> = SP1SC<SP1OuterGlobalContext, A>;Expand description
A type alias for the shard contexts used in the outer (wrap) stage of SP1 proving. Generic only in the AIR.
Aliased Type
pub struct OuterSC<A> { /* private fields */ }pub type OuterSC<A> = SP1SC<SP1OuterGlobalContext, A>;A type alias for the shard contexts used in the outer (wrap) stage of SP1 proving. Generic only in the AIR.
pub struct OuterSC<A> { /* private fields */ }