ShardVerifierConfigError

Type Alias ShardVerifierConfigError 

pub type ShardVerifierConfigError<GC, C> = ShardVerifierError<<GC as IopCtx>::EF, <C as MultilinearPcsVerifier<GC>>::VerifierError>;
Derive the error type from the jagged config.

Aliased Type

pub enum ShardVerifierConfigError<GC, C> {
Show 14 variants InvalidopeningArgument(JaggedPcsVerifierError<<GC as IopCtx>::EF, <C as MultilinearPcsVerifier<GC>>::VerifierError>), ConstraintsCheckFailed(SumcheckError), CumulativeSumsError(&'static str), PreprocessedChipIdMismatch(String, String), PreprocessedChipHeightMismatch(String), ChipOpeningLengthMismatch, MissingCpuChip, OpeningShapeMismatch(OpeningShapeError), GkrVerificationFailed(LogupGkrVerificationError<<GC as IopCtx>::EF>), InvalidPublicValues, InvalidShape, InvalidChipOrder(String, String), InvalidHeightBitDecomposition, HeightTooLarge,
}

Variants



InvalidopeningArgument(JaggedPcsVerifierError<<GC as IopCtx>::EF, <C as MultilinearPcsVerifier<GC>>::VerifierError>)

The pcs opening proof is invalid.



ConstraintsCheckFailed(SumcheckError)

The constraints check failed.



CumulativeSumsError(&'static str)

The cumulative sums error.



PreprocessedChipIdMismatch(String, String)

The preprocessed chip id mismatch.



PreprocessedChipHeightMismatch(String)

The error to report when the preprocessed chip height in the verifying key does not match the chip opening height.



ChipOpeningLengthMismatch

The chip opening length mismatch.



MissingCpuChip

The cpu chip is missing.



OpeningShapeMismatch(OpeningShapeError)

The shape of the openings does not match the expected shape.



GkrVerificationFailed(LogupGkrVerificationError<<GC as IopCtx>::EF>)

The GKR verification failed.



InvalidPublicValues

The public values verification failed.



InvalidShape

The proof has entries with invalid shape.



InvalidChipOrder(String, String)

The provided chip opened values has incorrect order.



InvalidHeightBitDecomposition

The height of the chip is not sent over correctly as bitwise decomposition.



HeightTooLarge

The height is larger than 1 << max_log_row_count.