Building blocks for defining AIRs.
Macros
- chip_
name - Macro to get the name of a chip.
Structs
- AirInteraction
- An interaction is a cross-table lookup.
- Binomial
Extension - A binomial extension element represented over a generic type
T. - Interaction
Scope Iter - An iterator over the variants of InteractionScope
- Public
Values - Stores all of a shard proof’s public values.
- Shard
Boundary - A shard boundary is a single shard that is being proven.
- Shard
Range - The range of the shard with respect to the program execution ordering.
- SubAir
Builder - A builder used to eval a sub-air. This will handle enforcing constraints for a subset of a
trace matrix. E.g. if a particular air needs to be enforced for a subset of the columns of
the trace, then the
SubAirBuildercan be used. - SubMatrix
RowSlices - A submatrix of a matrix. The matrix will contain a subset of the columns of
self.inner.
Enums
- Interaction
Scope - The scope of an interaction.
Constants
- POSEIDON_
NUM_ WORDS - The number of field elements in the poseidon2 digest.
- PROOF_
NONCE_ NUM_ WORDS - The number of 32 bit words in the SP1 proof’s proof nonce.
- PV_
DIGEST_ NUM_ WORDS - The number of 32 bit words in the SP1 proof’s committed value digest.
- SP1_
PROOF_ NUM_ PV_ ELTS - The number of non padded elements in the SP1 proofs public values vec.
Traits
- Base
AirBuilder - A trait which contains basic methods for building an AIR.
- Byte
AirBuilder - A trait which contains methods for byte interactions in an AIR.
- Empty
Message Builder - A message builder for which sending and receiving messages is a no-op.
- Extension
AirBuilder - A builder that can operation on extension elements.
- Instruction
AirBuilder - A trait which contains methods related to RISC-V instruction interactions in an AIR.
- Machine
Air - An AIR that is part of a multi table AIR arithmetization.
- Machine
AirBuilder - A trait that contains the common helper methods for building
SP1 recursionand SP1 machine AIRs. - Machine
Program - A program that defines the control flow of a machine through a program counter.
- Message
Builder - A builder that can send and receive messages (or interactions) with other AIRs.
- SP1Air
Builder - A trait which contains all helper methods for building SP1 machine AIRs.
- Septic
Extension AirBuilder - A builder that can operation on septic extension elements.
Functions
- timestamp_
from_ limbs - Returns a timestamp from a limbs array.
Type Aliases
- SP1Core
Public Values - A type alias for the public values of the SP1 core proof.