#[repr(C)]pub struct PublicValues<W1, W2, W3, T> {Show 39 fields
pub prev_committed_value_digest: [W1; 8],
pub committed_value_digest: [W1; 8],
pub prev_deferred_proofs_digest: [T; 8],
pub deferred_proofs_digest: [T; 8],
pub pc_start: W2,
pub next_pc: W2,
pub prev_exit_code: T,
pub exit_code: T,
pub is_execution_shard: T,
pub previous_init_addr: W2,
pub last_init_addr: W2,
pub previous_finalize_addr: W2,
pub last_finalize_addr: W2,
pub previous_init_page_idx: W2,
pub last_init_page_idx: W2,
pub previous_finalize_page_idx: W2,
pub last_finalize_page_idx: W2,
pub initial_timestamp: W3,
pub last_timestamp: W3,
pub is_timestamp_high_eq: T,
pub inv_timestamp_high: T,
pub is_timestamp_low_eq: T,
pub inv_timestamp_low: T,
pub global_init_count: T,
pub global_finalize_count: T,
pub global_page_prot_init_count: T,
pub global_page_prot_finalize_count: T,
pub global_count: T,
pub global_cumulative_sum: SepticDigest<T>,
pub prev_commit_syscall: T,
pub commit_syscall: T,
pub prev_commit_deferred_syscall: T,
pub commit_deferred_syscall: T,
pub initial_timestamp_inv: T,
pub last_timestamp_inv: T,
pub is_first_execution_shard: T,
pub is_untrusted_programs_enabled: T,
pub proof_nonce: [T; 4],
pub empty: [T; 4],
}Expand description
Stores all of a shard proof’s public values.
Fields
prev_committed_value_digest: [W1; 8]The committed_value_digest value before this shard.
committed_value_digest: [W1; 8]The hash of all the bytes that the guest program has written to public values.
prev_deferred_proofs_digest: [T; 8]The deferred_proof_digest value before this shard.
deferred_proofs_digest: [T; 8]The hash of all deferred proofs that have been witnessed in the VM. It will be rebuilt in recursive verification as the proofs get verified. The hash itself is a rolling poseidon2 hash of each proof+vkey hash and the previous hash which is initially zero.
pc_start: W2The shard’s start program counter.
next_pc: W2The expected start program counter for the next shard.
prev_exit_code: TThe expected exit code of the program before this shard.
exit_code: TThe expected exit code code of the program up to this shard. This value is only valid if halt has been executed.
is_execution_shard: TWhether or not the current shard is an execution shard.
previous_init_addr: W2The largest address that is witnessed for initialization in the previous shard.
last_init_addr: W2The largest address that is witnessed for initialization in the current shard.
previous_finalize_addr: W2The largest address that is witnessed for finalization in the previous shard.
last_finalize_addr: W2The largest address that is witnessed for finalization in the current shard.
previous_init_page_idx: W2The largest page idx that is witnessed for initialization in the previous shard.
last_init_page_idx: W2The largest page idx that is witnessed for initialization in the current shard.
previous_finalize_page_idx: W2The largest page idx that is witnessed for finalization in the previous shard.
last_finalize_page_idx: W2The largest page idx that is witnessed for finalization in the current shard.
initial_timestamp: W3The initial timestamp of the shard.
last_timestamp: W3The last timestamp of the shard.
is_timestamp_high_eq: TIf the high bits of timestamp is equal in this shard.
inv_timestamp_high: TThe inverse of the difference of the high bits of timestamp.
is_timestamp_low_eq: TIf the low bits of timestamp is equal in this shard.
inv_timestamp_low: TThe inverse of the difference of the low bits of timestamp.
global_init_count: TThe number of global memory initializations in the shard.
global_finalize_count: TThe number of global memory finalizations in the shard.
global_page_prot_init_count: TThe number of global page prot initializations in the shard.
global_page_prot_finalize_count: TThe number of global page prot finalizations in the shard.
global_count: TThe number of global interactions in the shard.
global_cumulative_sum: SepticDigest<T>The global cumulative sum of the shard.
prev_commit_syscall: TThe commit_syscall value of the previous shard.
commit_syscall: TWhether COMMIT syscall has been called up to this shard.
prev_commit_deferred_syscall: TThe commit_deferred_syscall value of the previous shard.
commit_deferred_syscall: TWhether COMMIT_DEFERRED syscall has been called up to this shard.
initial_timestamp_inv: TThe inverse to show that initial_timestamp != 1 in the shards that aren’t the first one.
last_timestamp_inv: TThe inverse to show that last_timestamp != 1 in all shards.
is_first_execution_shard: TWhether or not this shard is the first shard of the proof.
is_untrusted_programs_enabled: TWhether untrusted program support is enabled. This specifically will enable fetching instructions from memory during runtime and checking/setting page permissions.
proof_nonce: [T; 4]The nonce used for this proof.
empty: [T; 4]This field is here to ensure that the size of the public values struct is a multiple of 8.
Implementations
Sourceimpl PublicValues<u32, u64, u64, u32>
impl PublicValues<u32, u64, u64, u32>
Sourcepub fn to_vec<F: AbstractField>(&self) -> Vec<F>
pub fn to_vec<F: AbstractField>(&self) -> Vec<F>
Convert the public values into a vector of field elements. This function will pad the vector to the maximum number of public values.
Sourcepub fn range(&self) -> ShardRange
pub fn range(&self) -> ShardRange
Get the range of the shard.
TODO: deprecate this once recursion is fully streaming.
Sourcepub fn initialize(
&self,
pc_start_abs: u64,
enable_untrusted_programs: bool,
) -> Self
pub fn initialize( &self, pc_start_abs: u64, enable_untrusted_programs: bool, ) -> Self
Get the public values corresponding to initial state of the program for a non-execution shard.
Sourcepub fn update_state(&mut self, state: &PublicValues<u32, u64, u64, u32>)
pub fn update_state(&mut self, state: &PublicValues<u32, u64, u64, u32>)
Update the public values to the state.
Sourcepub fn update_initialized_state(
&mut self,
pc_start_abs: u64,
enable_untrusted_programs: bool,
)
pub fn update_initialized_state( &mut self, pc_start_abs: u64, enable_untrusted_programs: bool, )
Update the public values to the state, as a non-execution shard in the initial state of the program’s execution.
Sourcepub fn update_finalized_state(
&mut self,
timestamp: u64,
pc: u64,
exit_code: u32,
is_untrusted_programs_enabled: u32,
committed_value_digest: [u32; 8],
deferred_proofs_digest: [u32; 8],
nonce: [u32; 4],
)
pub fn update_finalized_state( &mut self, timestamp: u64, pc: u64, exit_code: u32, is_untrusted_programs_enabled: u32, committed_value_digest: [u32; 8], deferred_proofs_digest: [u32; 8], nonce: [u32; 4], )
Update the public values to the state, as a non-execution shard in the final state of the program’s execution.
Sourcepub fn update_finalized_state_from_public_values(
&mut self,
public_values: &PublicValues<u32, u64, u64, u32>,
)
pub fn update_finalized_state_from_public_values( &mut self, public_values: &PublicValues<u32, u64, u64, u32>, )
Similar to [update_finalized_state], but takes all the values from an existing public
values struct for convenience.
Sourceimpl<F: PrimeField32> PublicValues<[F; 4], [F; 3], [F; 4], F>
impl<F: PrimeField32> PublicValues<[F; 4], [F; 3], [F; 4], F>
Sourcepub fn commit_digest_bytes(&self) -> Vec<u8> ⓘ
pub fn commit_digest_bytes(&self) -> Vec<u8> ⓘ
Returns the commit digest as a vector of little-endian bytes.
Sourcepub fn initial_timestamp(&self) -> u64
pub fn initial_timestamp(&self) -> u64
Returns the initial timestamp.
Sourcepub fn last_timestamp(&self) -> u64
pub fn last_timestamp(&self) -> u64
Returns the last timestamp.
Sourcepub fn previous_init_addr(&self) -> u64
pub fn previous_init_addr(&self) -> u64
Returns the previous initialization address.
Sourcepub fn last_init_addr(&self) -> u64
pub fn last_init_addr(&self) -> u64
Returns the last initialization address.
Sourcepub fn previous_finalize_addr(&self) -> u64
pub fn previous_finalize_addr(&self) -> u64
Returns the previous finalize address.
Sourcepub fn last_finalize_addr(&self) -> u64
pub fn last_finalize_addr(&self) -> u64
Returns the last finalize address.
Sourcepub fn previous_init_page_idx(&self) -> u64
pub fn previous_init_page_idx(&self) -> u64
Returns the previous initialization page index.
Sourcepub fn last_init_page_idx(&self) -> u64
pub fn last_init_page_idx(&self) -> u64
Returns the last initialization page index.
Sourcepub fn previous_finalize_page_idx(&self) -> u64
pub fn previous_finalize_page_idx(&self) -> u64
Returns the previous finalize page index.
Sourcepub fn last_finalize_page_idx(&self) -> u64
pub fn last_finalize_page_idx(&self) -> u64
Returns the last finalize page index.
Sourcepub fn range(&self) -> ShardRange
pub fn range(&self) -> ShardRange
Returns the range of the shard.