AIR columns for the Poseidon2 hash function.
Structs
- Poseidon2
Degree3 Cols - A column layout for a poseidon2 permutation with degree 3 constraints.
- Poseidon2
State Cols - A column layout for the intermediate states of a Poseidon2 AIR across all rounds.
Constants
- NUM_
INTERNAL_ ROUNDS_ M1 - The number of internal rounds minus one.
- NUM_
POSEIDO N2_ DEGRE E3_ COLS - The number of columns in a Poseidon2 AIR with degree 3 constraints.
- POSEIDO
N2_ DEGRE E3_ COL_ MAP - A column map for a Poseidon2 AIR with degree 3 constraints.
Traits
- Poseidon2
Cols - Trait that describes getter functions for the permutation columns.
Functions
- permutation_
mut - Convert a row to a mutable
Poseidon2Colsinstance.