Prover components.
Structs
- Core
Proof Shape - The shape of the core proof. This and prover setup parameters should entirely determine the verifier circuit.
- Default
Trace Generator - A trace generator that used the default methods on chips for generating traces.
- Main
Trace Data - The main traces for a program, with a permit.
- Memory
Permit - A memory permit.
- Memory
Permitting - A semaphore that can be used to permit memory usage.
- Preprocessed
Data - The preprocessed data for a program.
- Preprocessed
Trace Data - The preprocessed traces for a program.
- Prover
Acquire Error - An error that occurs when acquiring a permit.
- Prover
Permit - A permit for the prover.
- Prover
Semaphore - A semaphore for the prover.
- Proving
Key - A proving key for an AIR prover.
- Shard
Data - A collection of main traces with a permit.
- Shard
Prover - A prover for the hypercube STARK, given a configuration.
Wrapped in Arc for cheap cloning to enable
spawn_blocking. - Shard
Prover Data - A proving key for a STARK.
- Shard
Prover Inner - Inner struct containing the actual prover data.
- Simple
Prover - A prover that proves traces sequentially using a single
AirProver. - Trace
Data - The total trace data for a shard.
- Traces
- A collection of traces.
- Zero
Check Poly - Zerocheck sumcheck polynomial.
- Zerocheck
CpuProver - Zerocheck data for the CPU backend.
- Zerocheck
CpuProver Data - The data required to produce zerocheck proofs on CPU.
Enums
- Memory
Permit Error - Errors that can occur when acquiring a memory permit.
Traits
- AirProver
- A prover for an AIR.
- Trace
Generator - A trace generator for a given machine.
- Zerocheck
Air - An AIR compatible with the standard zerocheck prover.
Functions
- increment_
y_ values - This function will increment the y0, y2, and y4 accumulators by the eval of the constraint polynomial at the points 0, 2, and 4.
- interpolate_
last_ var_ padded_ values - This function will calculate the column values where the last variable is set to 0, 2, and 4
and it’s a padded variable. The
row_0values are taken from the values matrix (which should have a height of 1). Therow_1values are all zero. - shape_
from_ record - Given a record, compute the shape of the resulting shard proof.
- simple_
prover - Create a
SimpleProverfrom a verifier with a single permit. - zerocheck_
fix_ last_ variable - This function will set the last variable to
alpha. - zerocheck_
sum_ as_ poly_ in_ last_ variable - This function will calculate the univariate polynomial where all variables other than the last are summed on the boolean hypercube and the last variable is left as a free variable. TODO: Add flexibility to support degree 2 and degree 3 constraint polynomials.
Type Aliases
- CpuShard
Prover - A CPU shard prover.
- CpuSimple
Prover - A CPU simple prover.
- PcsProof
- The PCS proof type associated to a shard context.
- Program
- The type of program this prover can make proofs for.
- Record
- The execution record for this prover.
- SP1Inner
PcsProver - The CPU prover components for a jagged PCS prover in SP1.
- SP1Merkle
Tree Prover - SP1Outer
PcsProver - The Jagged CPU prover components for the wrap step of recursion in SP1.