ShardProver

Struct ShardProver 

pub struct ShardProver<GC: IopCtx, SC: ShardContext<GC>, C: MultilinearPcsProver<GC, PcsProof<GC, SC>>> { /* private fields */ }
A prover for the hypercube STARK, given a configuration. Wrapped in Arc for cheap cloning to enable spawn_blocking.

Implementations

Source

impl<GC, Verifier, A, PcsComponents> ShardProver<GC, ShardContextImpl<GC, Verifier, A>, PcsComponents>
where GC: IopCtx, Verifier: MultilinearPcsVerifier<GC>, PcsComponents: DefaultJaggedProver<GC, Verifier>, A: ZerocheckAir<GC::F, GC::EF>,

pub fn new( verifier: ShardVerifier<GC, ShardContextImpl<GC, Verifier, A>>, ) -> Self

Create a new CPU prover.

Source

impl<GC: IopCtx, SC: ShardContext<GC>, C: MultilinearPcsProver<GC, PcsProof<GC, SC>>> ShardProver<GC, SC, C>

pub fn from_components( trace_generator: DefaultTraceGenerator<GC::F, SC::Air, CpuBackend>, logup_gkr_prover: GkrProverImpl<GC, SC>, pcs_prover: JaggedProver<GC, PcsProof<GC, SC>, C>, ) -> Self

Create a new ShardProver from its components.

pub fn trace_generator( &self, ) -> &DefaultTraceGenerator<GC::F, SC::Air, CpuBackend>

Access the trace generator.

pub fn logup_gkr_prover(&self) -> &GkrProverImpl<GC, SC>

Access the logup GKR prover.

pub fn pcs_prover(&self) -> &JaggedProver<GC, PcsProof<GC, SC>, C>

Access the PCS prover.

Source

impl<GC: IopCtx, SC: ShardContext<GC>, C: DefaultJaggedProver<GC, SC::Config>> ShardProver<GC, SC, C>

pub fn all_chips(&self) -> &[Chip<GC::F, SC::Air>]

Get all the chips in the machine.

pub fn machine(&self) -> &Machine<GC::F, SC::Air>

Get the machine.

pub fn num_pv_elts(&self) -> usize

Get the number of public values in the machine.

pub fn max_log_row_count(&self) -> usize

Get the maximum log row count.

pub fn setup_from_preprocessed_data_and_traces( &self, pc_start: [GC::F; 3], initial_global_cumulative_sum: SepticDigest<GC::F>, preprocessed_traces: Traces<GC::F, CpuBackend>, enable_untrusted_programs: GC::F, ) -> (ShardProverData<GC, SC, C>, MachineVerifyingKey<GC>)

Setup from preprocessed data and traces.

pub async fn setup_with_initial_global_cumulative_sum( &self, program: Arc<Program<GC, SC>>, initial_global_cumulative_sum: SepticDigest<GC::F>, setup_permits: ProverSemaphore, ) -> (PreprocessedData<ProvingKey<GC, SC, Self>>, MachineVerifyingKey<GC>)

Setup from a program with a specific initial global cumulative sum.

pub fn prove_shard_with_data( &self, data: ShardData<GC, SC, C>, challenger: GC::Challenger, ) -> (ShardProof<GC, PcsProof<GC, SC>>, ProverPermit)

Generate a proof for a given execution record.